/**
 * ROOT->BLOP and BLOP->ROOT histogram conversions.
 * Only works for uniform binning.
 */
#ifndef __bloproot_h
#define __bloproot_h
#include <blop.h>
#include <TH1D.h>
#include <TH2D.h>
#include <TH3D.h>
namespace blop
{


/// Convert ROOT 1D histogram to BLOP histogram.
extern void r2b_convert(const TH1D& r, hist& h);


/// Convert BLOP 1D histogram to ROOT histogram.
extern void b2r_convert(const hist& h, TH1D& r);


/// Convert ROOT 2D histogram to BLOP histogram.
extern void r2b_convert(const TH2D& r, hist& h);

/// Convert BLOP 2D histogram to ROOT histogram.
extern void b2r_convert(const hist& h, TH2D& r);


/// Convert ROOT 3D histogram to BLOP histogram.
extern void r2b_convert(const TH3D& r, hist& h);


/// Convert BLOP 3D histogram to ROOT histogram.
extern void b2r_convert(const hist& h, TH3D& r);


/// Read all ROOT histos in a ROOT file into a map of BLOP histos.
extern void readHistos(const std::string& fileName, std::map<std::string, hist>& histos);
// (Note: cannot read into ROOT histograms because ROOT is incompatible
//  with itself: cannot append a ROOT histo to a vector/map.)


}
#endif
