#ifndef __CINT__
#include <bloproot.h>
using namespace std;
using namespace blop;
int exa(int argc, char* argv[]);
int main(int argc, char*argv[]) { return exa(argc, argv); }
#endif


int exa(int argc, char* argv[])
{

  // BLOP histogram filling:
  hist h(-5.0, 5.0, 100, "Random variable", "Entries", "Gaussian data");
  function gauss_generator = random_gauss(0.0,1.0);
  const vector<var> dummyvar;
  for ( int i=0 ; i<10000 ; ++i )
    h.fill(gauss_generator.eval_dbl(dummyvar));

  // BLOP fit model to data:
  function f=PAR(1)*1.0/sqrt(2.0*M_PI*PAR(2)*PAR(2))*exp(-(_1-PAR(3))*(_1-PAR(3))/(2.0*PAR(2)*PAR(2)))*(h.max(1)-h.min(1))/h.bins(1);
  f.param(1, 8000.0);
  f.param(2, 0.8);
  f.param(3, 0.1);
  fitresult r=fit<poisson_chi2>(h, f);
  cout << "PAR(1): " << f.param(1) << " +/- " << sqrt(r.covar(1,1)) << endl;
  cout << "PAR(2): " << f.param(2) << " +/- " << sqrt(r.covar(2,2)) << endl;
  cout << "PAR(3): " << f.param(3) << " +/- " << sqrt(r.covar(3,3)) << endl;
  cout << "chi^2/ndf: " << r.chi2 << "/" << r.N << " = " << r.chi2/r.N << endl;

  // BLOP multi-page postscript output:
  mpps bm("exa.eps");
  // Plot with BLOP facilities:
  set::clear();
  set::title("A histograming example");
  set::xlabel(h.axistitle(1));
  set::ylabel(h.rangetitle());
  set::xrange(-5.0, 5.0);
  mplot(h).drawstyle(sxyerrorbars().clip_errorbars(true)).pointcolor(red).linecolor(red).pointtype(fsquare()).legend(h.legend());
  mplot(_1, f(_1)).drawstyle(lines()).linecolor(green).linestyle(sym::solid).legend("Gaussian model");
  // Print the above stuff to mpps terminal:
  bm.print();
  // Print the above stuff to blopeps terminal:
  blopeps::print("exa0.beps");
  // Plot with quick plot (shorthand) facility of the histograming package:
  // Shorthand print to mpps:
  hist::qplot(bm).title("A histograming example")<<h<<f<<(var)"Gauss model";
  // Shorthand print to blopeps file:
  hist::qplot("exa1.beps").title("A histograming example")<<h<<f<<(var)"Gauss model";
  // Close mpps terminal:
  bm.close();

  // ROOT histogram filling, then convert to BLOP abd plot via BLOP.
  TH1D rTH1D("th1d", "Gaussian data;Random variable;Entries", 100, -5.0, 5.0);
  for ( int i=0 ; i<10000 ; ++i )
    rTH1D.Fill(gauss_generator.eval_dbl(dummyvar));
  hist bTH1D;
  r2b_convert(rTH1D, bTH1D);
  hist::qplot("exaroot.beps").title("A ROOT to BLOP histograming example")<<bTH1D;

  return 0;
}

